# coding=utf-8
'''
zx08443 发送邮件，简单做了一个数据分离，配置的数据单独读取data文件获取

'''
import time
import smtplib
from smtplib import SMTP_SSL
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart
from email.header import Header
from testdata import email


# 发送邮件，发送测试报告html
def send_email(newfile):
    f = open(newfile, 'rb')
    mail_body = f.read()
    f.close()
    today = time.strftime('%Y-%m-%d')
    smtpserver = email.data['smtpserver']
    title = email.data['title']
    user = email.data['user']
    password = email.data['password']
    sender = email.data['sender']
    receiver = email.data['receiver']
    cc = email.data['cc']

    # 发送邮件主题
    subject = title + 'api测试报告%s' % today
    msg = MIMEMultipart('mixed')
    msg_html1 = MIMEText(mail_body,
                         'html', 'utf-8')  # 邮件内容
    msg.attach(msg_html1)
    msg_html2 = MIMEText('\n' + "<font  size='5' color='red'>注：请点击链接查看详情</font> ", 'html', 'utf-8')
    msg.attach(msg_html2)
    msg_html = MIMEText(mail_body, 'html', 'utf-8')  # 邮件附件
    msg_html['Content-Disposition'] = 'attachment; filename="TestReport.html"'
    msg.attach(msg_html)
    msg['From'] = sender
    msg['To'] = ';'.join(receiver)
    msg['Cc'] = ';'.join(cc)
    receiver = receiver + cc
    msg['Subject'] = Header(subject, 'utf-8');
    # 连接发送邮件
    try:
        smtp = SMTP_SSL(smtpserver)
        smtp.login(user, password)
        smtp.sendmail(sender, receiver, msg.as_string())
        smtp.quit()
        print("邮件发送成功！")
    except smtplib.SMTPException:
        print("Error:无法发送邮件！")



# coding=utf-8
"""
作者：vissy@zhu
"""

import requests
from testdata import http


class ConfigHttp:

    def __init__(self):
        global scheme, api_url, www_url, web_url, port
        scheme = http.data["scheme"]
        api_url = http.data["api_url"]
        www_url = http.data["www_url"]
        web_url = http.data["web_url"]
        port = http.data["port"]
        self.headers = {}
        # self.params = {}
        self.data = {}
        self.url = {}
        # self.files = {}
        self.state = 0

    def set_url(self, url):
        """
        set url
        :param: interface url
        :return:
        """
        self.__url = scheme + '://' + api_url + url

    def set_www_url(self, url):
        """
        set url
        :param: interface url
        :return:
        """
        self.__url = scheme + '://' + www_url + url

    def set_web_url(self, url):
        """
        set url
        :param: interface url
        :return:
        """
        self.__url = scheme + '://' + web_url + url

    def set_headers(self, header):
        """
        set headers
        :param header:
        :return:
        """
        self.headers = header

    def set_params(self, param):
        """
        set params
        :param param:
        :return:
        """
        self.params = param

    def set_data(self, data):
        """
        set data
        :param data:
        :return:
        """
        self.__data = data

    # defined http_data.py get method
    def get(self):
        """
        defined get method
        :return:
        """
        try:
            response = requests.get(self.url, headers=self.headers, params=self.params)
            # response.raise_for_status()
            return response
        except TimeoutError:
            self.logger.error("Time out!")
            return None

    # defined http_data.py post method
    # include get params and post data
    # uninclude upload file
    def post(self):
        """
        defined post method
        :return:
        """
        try:
            response = requests.post(self.__url,  headers=self.headers,json=self.__data)
            # response.raise_for_status()
            return response
        except TimeoutError:
            return None



# coding=utf-8
"""
zx08443
"""

import pymysql
from testdata import db


# 数据库连接
def connectdb():
    connect = pymysql.connect(host=db.data["host"], user=db.data["username"], password=db.data["password"],
                              port=db.data["port"], db=db.data["database"])  # 连接数据库
    c = connect.cursor()
    return connect, c  # 返回游标，执行sql语句，返回连接参数，是为了执行数据的更新sql，比如update和delete。



# coding=utf-8
"""
zx08443 生成HTML测试报告
"""

from HTMLTestRunner import HTMLTestRunner


def result():
    filename = 'result.html'
    fp = open(filename, 'wb')
    runner = HTMLTestRunner.HTMLTestRunner(stream=fp, title=u'测试报告', description=u'用例执行情况：')
    return runner, fp  # 为什么要返回fp呢，因为调用这个方法的时候，还没有执行用例，所以返回fp，执行完用例，在关闭文件。



# coding=utf-8
"""
作者：vissy@zhu
"""
import setuptools

setuptools.setup(
    name="lyhapi",  # Replace with your own username
    version="0.0.5",
    author="vissyzhu",
    author_email="1209354095@qq.com",
    description="lyhcc information retriver",
    url="https://github.com/vissyzhu/lyhapi.git",
    license='MIT',
    packages=setuptools.find_packages(),
    zip_safe=False
)
